==> spellathon-5.4.tar.gz: spellathon-5.4/src/logic/util.cc <==
/*
 * Copyright (c) 2008, Girish Rao
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright 
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the <ORGANIZATION> nor the names of its contributors 
 * may be used to endorse or promote products derived from this software 
 * without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS 
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT i
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */

#include <errno.h>
#include <stdarg.h>

#include "util.h"

namespace Spellathon
{
	
	void *
	memalloc(size_t newsize)
	{
		void *r;
	
		if ( (r = malloc(newsize)) == NULL) 
			errexit(1, "Can't allocate memory");
		return r;
	}
	
	void *
	memresize(void *mem, size_t newsize)
	{
		void *r;
	
		if ( (r = realloc(mem, newsize)) == NULL) 
			errexit(1, "Can't allocate memory");
		return r;
	}
	
	void
	errexit(int syserr, const char *msg, ...) throw (string)
	{
		va_list	ap;
	
		va_start(ap, msg);
		char s[256];
		vsprintf(s, msg, ap);
		if (syserr)
			sprintf(s + strlen(s), ": %s", strerror(errno));
		va_end(ap);
		throw string(s);
	}
	
}

==> spellathon-5.21.tar.gz: spellathon-5.21/src/logic/util.cc <==
/*
 * Copyright (c) 2008, Girish Rao
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 * Redistributions of source code must retain the above copyright 
 * notice, this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the <ORGANIZATION> nor the names of its contributors 
 * may be used to endorse or promote products derived from this software 
 * without specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS 
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) 
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT i
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
 * SUCH DAMAGE.
 */

#include <errno.h>
#include <stdarg.h>

#include "util.h"

namespace Spellathon
{
	
	void *
	memalloc(size_t newsize)
	{
		void *r;
	
		if ( (r = malloc(newsize)) == NULL) 
			spth_error(1, "Can't allocate memory");
		return r;
	}
	
	void *
	memresize(void *mem, size_t newsize)
	{
		void *r;
	
		if ( (r = realloc(mem, newsize)) == NULL) 
			spth_error(1, "Can't allocate memory");
		return r;
	}
	
	void
	spth_error(bool syserr, const char *msg, ...) throw (string)
	{
		va_list	ap;
	
		va_start(ap, msg);
		char s[256];
		vsprintf(s, msg, ap);
		if (syserr)
			sprintf(s + strlen(s), ": %s", strerror(errno));
		va_end(ap);
		throw string(s);
	}
	
}
